durationtools
=============

.. automodule:: abjad.tools.durationtools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.durationtools.Duration.Duration
      ~abjad.tools.durationtools.Multiplier.Multiplier
      ~abjad.tools.durationtools.Offset.Offset
